NullBuilder

Struct NullBuilder 

pub struct NullBuilder { /* private fields */ }
Available on crate features test-util only.
Creates an instance of Null.

Access through Null::builder().

Implementations

Source

impl NullBuilder

pub fn memory(self, memory: OpaqueMemory) -> Self

The memory provider to use in memory-related stream operations.

The null stream never reserves memory, so the only purpose of this is to allow the user of the null stream to call memory() and reserve() via the HasMemory and Memory traits that every stream implements.

Optional. Defaults to using the Rust global allocator.

pub fn build(self) -> Null

Builds the NullStream with the provided configuration.