pub struct NullBuilder { /* private fields */ }Available on crate features
test-util only.Expand description
Creates an instance of Null.
Access through Null::builder().
Implementations
Sourceimpl NullBuilder
impl NullBuilder
Sourcepub fn memory(self, memory: OpaqueMemory) -> Self
pub fn memory(self, memory: OpaqueMemory) -> Self
The memory provider to use in memory-related stream operations.
The null stream never reserves memory, so the only purpose of this is to allow the user
of the null stream to call memory() and reserve() via the HasMemory and Memory
traits that every stream implements.
Optional. Defaults to using the Rust global allocator.